@@ -367,6 +367,20 @@ class Bitbucket(AtlassianRestAPI):
                                                                                            repositorySlug=repository)
         return self.post(url)
 
+    def reindex_repo_dev_panel(self, project, repository):
+        """
+        Reindex all of the Jira issues related to this repository, including branches and pull requests.
+        This automatically happens as part of an upgrade, and calling this manually should only be required
+        if something unforeseen happens and the index becomes out of sync.
+        The authenticated user must have REPO_ADMIN permission for the specified repository to call this resource.
+        :param project:
+        :param repository:
+        :return:
+        """
+        url = 'rest/jira-dev/1.0/projects/{projectKey}/repos/{repositorySlug}/reindex'.format(projectKey=project,
+                                                                                              repositorySlug=repository)
+        return self.post(url)
+
     def check_reindexing_status(self):
         """
         Check reindexing status
